@@ -31,13 +31,14 @@ def newMenu(obj, intro=""):
     while m.run:
         print(intro)
         m.banner(m.genmenu())
+        
         try:
             opt = input("\n"+m.promp)
-            m.genfuncs().get(opt)()
-        except TypeError:
-            print(m.excepterror)
-        except ValueError:
-            print(m.exceptnull)
+            m.genfuncs().get(opt)(m)
+        #except TypeError:
+         #   print(m.excepterror)
+        #except ValueError:
+         #   print(m.exceptnull)"""
         except KeyboardInterrupt:
             print(m.exceptki)
             sys.exit()
